@@ -7,7 +7,7 @@ from ubiops_cli.src.helpers.formatting import print_list, print_item, format_yam
 from ubiops_cli.src.helpers.options import *
 
 
-LIST_ITEMS = ['last_updated', 'version', 'deployment_mode', 'status', 'labels']
+LIST_ITEMS = ['last_updated', 'version', 'status', 'labels']
 
 
 @click.group(["deployment_versions", "versions"], short_help="Manage your deployment versions")
@@ -85,7 +85,8 @@ def versions_get(deployment_name, version_name, output_path, quiet, format_):
     maximum_idle_time: 300
     request_retention_mode: none
     request_retention_time: 604800
-    deployment_mode: express
+    maximum_queue_size_express: 100
+    maximum_queue_size_batch: 100000
     ```
     """
 
@@ -127,9 +128,11 @@ def versions_get(deployment_name, version_name, output_path, quiet, format_):
 @MIN_INSTANCES
 @MAX_INSTANCES
 @MAX_IDLE_TIME
-@DEPLOYMENT_MODE
+@DEPLOYMENT_MODE_DEPRECATED
 @RETENTION_MODE
 @RETENTION_TIME
+@MAX_QUEUE_SIZE_EXPRESS
+@MAX_QUEUE_SIZE_BATCH
 @VERSION_LABELS
 @VERSION_DESCRIPTION
 @VERSION_YAML_FILE
@@ -155,11 +158,10 @@ def versions_create(deployment_name, version_name, yaml_file, format_, **kwargs)
     maximum_idle_time: 300
     request_retention_mode: none
     request_retention_time: 604800
-    deployment_mode: express
+    maximum_queue_size_express: 100
+    maximum_queue_size_batch: 100000
     ```
 
-    Provide either deployment mode 'express' or 'batch', default is 'express'.
-
     Those parameters can also be provided as command options. If both a `<yaml_file>` is set and
     options are given, the options defined by `<yaml_file>` will be overwritten by the specified command options.
     The version name can either be passed as command argument or specified inside the yaml file using `<version_name>`.
@@ -175,6 +177,12 @@ def versions_create(deployment_name, version_name, yaml_file, format_, **kwargs)
     assert 'version_name' in yaml_content or version_name, 'Please, specify the version name in either ' \
                                                            'the yaml file or as a command argument'
 
+    if format_ != 'json' and ('deployment_mode' in yaml_content or kwargs['deployment_mode']):
+        click.secho(
+            "Deprecation warning: 'deployment_mode' is deprecated. From now on, both direct and batch requests can be "
+            "made to the same deployment version.", fg='red'
+        )
+
     kwargs = define_deployment_version(kwargs, yaml_content, extra_yaml_fields=['deployment_file'])
 
     if format_ != 'json' and kwargs['memory_allocation'] and not kwargs['instance_type']:
@@ -215,6 +223,8 @@ def versions_create(deployment_name, version_name, yaml_file, format_, **kwargs)
 @MAX_IDLE_TIME
 @RETENTION_MODE
 @RETENTION_TIME
+@MAX_QUEUE_SIZE_EXPRESS
+@MAX_QUEUE_SIZE_BATCH
 @VERSION_LABELS
 @VERSION_DESCRIPTION
 @QUIET
@@ -235,6 +245,8 @@ def versions_update(deployment_name, version_name, yaml_file, new_name, quiet, *
     maximum_idle_time: 300
     request_retention_mode: none
     request_retention_time: 604800
+    maximum_queue_size_express: 100
+    maximum_queue_size_batch: 100000
     ```
 
     You may want to change some deployment options, like, `<maximum_instances>` and
