@@ -23,7 +23,7 @@ OFFSET = click.option(
 
 # Formatting output
 LOGS_FORMATS = click.option(
-    '-fmt', '--format', 'format_',  default='reference', help="The output format",
+    '-fmt', '--format', 'format_',  default='oneline', help="The output format",
     type=click.Choice(['oneline', 'reference', 'extended', 'json'], case_sensitive=False), show_default=True
 )
 REQUESTS_FORMATS = click.option(
@@ -178,10 +178,10 @@ MAX_IDLE_TIME = click.option(
     '-t', '--maximum_idle_time', required=False, default=None, type=int, metavar='<int>',
     help="Maximum idle time before shutting down instance (seconds)"
 )
-DEPLOYMENT_MODE = click.option(
+DEPLOYMENT_MODE_DEPRECATED = click.option(
     '-dm', '--deployment_mode', required=False, default=None,
     type=click.Choice(['express', 'batch'], case_sensitive=False),
-    help="The type of the deployment version"
+    help="[DEPRECATED] The type of the deployment version"
 )
 RETENTION_MODE = click.option(
     '-rtm', '--request_retention_mode', required=False, default=None,
@@ -192,6 +192,14 @@ RETENTION_TIME = click.option(
     '-rtt', '--request_retention_time', required=False, default=None, type=int, metavar='<int>',
     help="Number of seconds to store requests to the version"
 )
+MAX_QUEUE_SIZE_EXPRESS = click.option(
+    '-qse', '--maximum_queue_size_express', required=False, default=None, type=int, metavar='<int>',
+    help="Maximum number of queued express requests to the version"
+)
+MAX_QUEUE_SIZE_BATCH = click.option(
+    '-qsb', '--maximum_queue_size_batch', required=False, default=None, type=int, metavar='<int>',
+    help="Maximum number of queued batch requests to the version"
+)
 
 VERSION_LABELS = click.option(
     '-lb', '--labels', 'version_labels', required=False, default=None, multiple=True, type=str,
